#
# spec file for package libratbag
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2019 Matthias Bach <marix@marix.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libratbag
Version:        0.9.904
Release:        10.7
Summary:        Configuration library for gaming mice
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://github.com/libratbag/libratbag
Source:         %name-%version.tar.xz
Patch1:         no-git.diff
Patch2:         shebang-env.diff
Patch3:         install-daemon-into-sbindir.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkg-config
BuildRequires:  python3-evdev
BuildRequires:  python3-gobject
BuildRequires:  python3-lxml
BuildRequires:  swig
BuildRequires:  systemd-rpm-macros
BuildRequires:  valgrind
BuildRequires:  pkgconfig(check) >= 0.9.10
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libsystemd) >= 227
BuildRequires:  pkgconfig(libudev) >= 196
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(systemd)

%description
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

%package -n liblur3
Summary:        Logitech Unifying Receiver configuration library
Group:          System/Libraries

%description -n liblur3
A library to configure and handle the /dev hidraw devices belonging
to the "Unifying" wireless receiver.

%package -n ratbagd
Summary:        Service granting access to the configuration options of gaming mice
Group:          Hardware/Other
Recommends:     libratbag-tools
Requires(pre):  group(games)

%description -n ratbagd
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

This subpackage contains the daemon managing access to the hardware.

%package devel
Summary:        Development files for the libratbag game mouse config library
Group:          Development/Libraries/C and C++
Requires:       liblur3 = %version

%description devel
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

This subpackage contains the files needed to build programs with
libratbag.

%package tools
Summary:        Utilities for configuring gaming mice
Group:          Hardware/Other
Requires:       python3-evdev
Requires:       ratbagd

%description tools
libratbag is a configuration library for gaming mice. It provides a
generic way to access the various features exposed by these mice and
abstracts away hardware-specific and kernel-specific quirks.

This subpackage contains the ratbag utilities allowing to inspect and configure
mice.

%prep
%setup -q
%patch -P 1 -P 2 -P 3 -p1

%build
%meson -Ddocumentation=false -Ddbus-group=games \
	--includedir="%_includedir/%name"
%meson_build

%check
%meson_test

%install
%meson_install
mkdir -p "%buildroot/%_sbindir"
ln -s service "%buildroot/%_sbindir/rcratbagd"
chmod -x "%buildroot/%_datadir/%name/devices/logitech-g402.device"  # Fix this file for some reaseon being executable
%fdupes %buildroot/%_prefix

%post   -n liblur3 -p /sbin/ldconfig
%postun -n liblur3 -p /sbin/ldconfig

%pre -n ratbagd
%service_add_pre ratbagd.service

%post -n ratbagd
%service_add_post ratbagd.service

%preun -n ratbagd
%service_del_preun ratbagd.service

%postun -n ratbagd
%service_del_postun ratbagd.service

%files -n liblur3
%defattr(-,root,root)
%_libdir/liblur.so.3*

%files devel
%defattr(-,root,root)
%_libdir/liblur.so
%_libdir/pkgconfig/*.pc
%_includedir/libratbag/

%files -n ratbagd
%defattr(-,root,root)
%_sbindir/ratbagd
%_sbindir/rcratbagd
%_unitdir/*.service
%_datadir/dbus-1/
%_datadir/%name/
%_mandir/man8/*

%files tools
%defattr(-,root,root)
%_bindir/lur-command
%_bindir/ratbagctl
%_mandir/man1/*

%changelog
* Wed Jan 30 2019 marix@marix.org
- Update to version 0.9.904:
  * Added Devices:
    + Logitech G PowerPlay
    + Logitech G Pro
    + Logitech G402
    + Logitech G502 HERO
    + Logitech MX Anywhere 2
    + Logitech MX Anywhere 2S
    + Logitech MX Master 2S
    + Steelseries Rival 600
  * Improved Devices:
    + All supported Roccat Devices
    + Logitech G102/203
    + Logitech G502
    + Logitech G600
    + Logitech G603
    + Logitech G903
    + Logitech MX Master
  * Improved error messages provided by the command line tools.
* Tue Oct 16 2018 opensuse-packaging@opensuse.org
- Update to version 0.9.903:
  * Adds GetSvgFd() function on D-BUS required by Piper
  * Add a --version commandline argument ratbagd
  * Added support for the Steelseries Sensei Raw
  * Added support for the Logitech G600
  * Added support for the Logitech G302
* Tue Jul 31 2018 marix@marix.org
- Drop rpmlint configuration as the D-Bus service of the package
  has been whitelisted via bsc#1076467.
* Sat Jul 28 2018 marix@marix.org
- Ensure that group games is present.
* Fri Jul 27 2018 marix@marix.org
- Add install-daemon-into-sbindir-patch.patch: Installs ratbagd
  into /usr/sbin as can only be run by root.
* Tue Jul 10 2018 marix@marix.org
- Move the daemon into a separate subpackage as applications like
  piper can use it without having the command line tools installed.
* Thu Jul  5 2018 marix@marix.org
- Run tests as part of package build.
- Fix disabling of documentation build.
* Thu Jul  5 2018 marix@marix.org
- Suppress the suse-dbus-unauthorized-service lintian error for
  easier testing.
* Wed Jul  4 2018 marix@marix.org
- Update to new upstream release 0.9.902:
  * Add Steelserices Sensei 310
- Remove 0001-meson-dbus-support-build-time-option-to-restrict-D-B.patch
  as it was merged upstream.
* Wed Jul  4 2018 marix@marix.org
- Recovered the deleted package from the hardware project.
- Switch to source retrieved via obs_scm.
* Mon Jan 29 2018 jengelh@inai.de
- Update to new upstream release 0.9.901
  * Fixed a stack buffer overflow that was triggerable
    with dbus-send
  * multiple D-Bus calls caused a 3-byte stack overwrite and
    resulted in a segfault
  * ratbagd_button_set_key() D-Bus callback allowed
    another stack buffer overflow
- Remove 0001-meson-fix-default-value-in-meson_options.txt.patch
- Add 0001-meson-dbus-support-build-time-option-to-restrict-D-B.patch
* Sat Nov 11 2017 jengelh@inai.de
- Update to new upstream release 0.9.900
  * libratbag is not a library anymore. Instead, the ratbagd
    project was merged into libratbag and the main way to
    interact with libratbag is now via its DBus interface. This
    is because anything using libratbag needs to run as root to
    have the required permissions. At that point, an abstraction
    daemon is needed anyway to use it from a GUI app.
- Add 0001-meson-fix-default-value-in-meson_options.txt.patch
  to fix an error during configure step.
- Add shebang-env.diff, no-git.diff .
* Thu Jun  8 2017 jengelh@inai.de
- Update to new upstream release 0.9
  * 2 new drivers (G300 and G-Skill)
  * a brand new LED API
  * a new commit API for sending profiles at once, which should
    reduce the communications between the host and the device
  * some shiny new SVGs
  * convert some Logitech devices to the commit API
  * manpage added for lur-command
* Sat Oct 22 2016 jengelh@inai.de
- Update to new upstream release 0.5
  * No changelog was provided
* Fri Jul  1 2016 jengelh@inai.de
- Update to new git snapshot 0.4.g39
  * add support for Logitech G700, and G700 over wireless
  * enable metadata parsing on G500
  * add profile parsing on G9, button definitions and mappings for G9
  * add G502 and G700 svg data
* Thu Nov 12 2015 jengelh@inai.de
- Initial package (version 0~git620) for build.opensuse.org
